@@ -65,19 +65,19 @@ _WEEK_INTERVAL = 60 * 60 * 12
 How often to check what the current week is. By default, it is twice a day.
 """
 
-_CUR_SCHEDULE_URL = "http://www.nfl.com/liveupdate/scorestrip/ss.xml"
-"""
-Pinged infrequently to discover the current week number, year and week type.
-The actual schedule of games is taken from the schedule module.
-"""
+# _CUR_SCHEDULE_URL = "http://www.nfl.com/liveupdate/scorestrip/ss.xml"
+# """
+# Pinged infrequently to discover the current week number, year and week type.
+# The actual schedule of games is taken from the schedule module.
+# """
 
-# _CUR_SCHEDULE_URL = "http://static.nfl.com/liveupdate/scorestrip/postseason/ss.xml" 
-# """ 
-# The URL for the XML schedule of the post season. This is only used 
-# during the post season. 
-#  
-# TODO: How do we know if it's the post season? 
-# """ 
+_CUR_SCHEDULE_URL = "http://static.nfl.com/liveupdate/scorestrip/postseason/ss.xml"
+"""
+The URL for the XML schedule of the post season. This is only used
+during the post season.
+
+TODO: How do we know if it's the post season?
+"""
 
 _cur_week = None
 """The current week. It is updated infrequently automatically."""
